from ctypes import *
import os
import platform

lib_path = os.path.join(
    os.path.dirname(os.path.realpath(__file__)),
    'so/libsv.so'
)
c_sn_verifier = cdll.LoadLibrary(lib_path)

c_sn_verifier.c_verify_token.argtypes = []
c_sn_verifier.c_verify_token.restype = c_bool


class SerialNum(object):

    @staticmethod
    def verify():
        val = c_sn_verifier.c_verify_token()
        return val


if __name__ == '__main__':
    print(SerialNum.verify())


import setuptools

setuptools.setup(
    name="pysnver",
    version="0.2.2",
    description="python sn verify",
    packages=['pysnver'],
    package_data={'pysnver': ['so/*']},
    classifiers=[
        "Programming Language :: Python :: 3"
    ],
)

